import anime from 'animejs';

export class LoadingSkeleton {
    private _div: HTMLElement;
    private _animation!: any;

    constructor(div: HTMLElement) {
        this._div = div;
    }

    public start(): void {
        this._animation = anime({
            targets: this._div,
            backgroundPosition: [0, 200],
            duration: 1500,
            easing: 'linear',
            loop: true,
        });
    }

    public async stop(): Promise<void> {
        this._animation?.pause();
        const stopAnimation = anime({
            targets: this._div,
            opacity: [1, 0],
            duration: 400,
            easing: 'easeInOutQuad',
        });

        await stopAnimation.finished; // use `.finished` instead of `.promise`
    }
}

export class Loading {
    private _status: boolean;
    private _promise: Promise<void>;
    private _resolver: (() => void);

    constructor() {
        this._status = false;
        this._resolver = (() => (null));
        this._promise = new Promise<void>((resolve) => {
            this._resolver = resolve;
        });
    }

    public getStatus(): boolean {
        return this._status;
    }

    public setStatus(value: boolean): boolean {
        this._status = value;

        if (value) this._resolver();
        // Create a new promise when the status is set to false again
        else {
            this._promise = new Promise<void>((resolve) => {
                this._resolver = resolve;
            });
        }
        return this._status;
    }

    public getPromise(): Promise<void> {
        if (this._status)
            return Promise.resolve();
        else {
            return this._promise;
        }
    }
}

