let observer: IntersectionObserver;

function checkViewportObserver() {
    if (observer) return;

    // When scrolling so that intersection observer detects the viewport
    observer = new IntersectionObserver(
        (entries) => {
            entries.forEach(entry => {
                const eventName = entry.isIntersecting ? 'enterViewport' : 'exitViewport';
                entry.target.dispatchEvent(new CustomEvent(eventName));
            });
        }
    );
}

export default function viewport(element: HTMLElement) {
    checkViewportObserver();
    observer.observe(element);

    return {
        destroy() {
            observer.unobserve(element);
        }
    }
}
